# Aphid

This is a Rust implementation of the "Aphid" method,
following its specifications within Nicolas Galtier's draft paper
*Phylogenetic conflicts:
distinguishing gene flow from incomplete lineage sorting* (2023).

Sources available at: https://gitlab.mbb.cnrs.fr/ibonnici/aphid/.

## Build instructions

### With Apptainer/Singularity

Aphid can be run from an apptainer
provided you have [Apptainer] (aka. Singularity) installed.

First, build the container image as root:

```sh
# Get definition file.
curl -L \
  https://gitlab.mbb.cnrs.fr/ibonnici/aphid/-/jobs/artifacts/rust-implementation/raw/singularity.def?job=container-recipes \
  > aphid.def # (or download by hand)

# Build image.
sudo apptainer build aphid.sif aphid.def
```

Then run the container as regular user:

```sh
./aphid.sif <arguments>
```

[Apptainer]: https://apptainer.org/

### With Docker

Aphid can be run from a docker container,
provided you have [Docker] installed.

First, build the container image:
```sh
docker buildx build -t aphid \
  https://gitlab.mbb.cnrs.fr/ibonnici/aphid/-/jobs/artifacts/rust-implementation/raw/Dockerfile?job=container-recipes
```

Then run the container:
```sh
docker run --rm -it -v ${PWD}:/home/aphid aphid <arguments>
```

[Docker]: https://www.docker.com/

### Manual compilation

The program is still fairly easy to compile yet,
provided you have [git], [torch] and a [rust stable toolchain] installed.

First clone and compile the project:

```sh
git clone --recursive https://gitlab.mbb.cnrs.fr/ibonnici/aphid/ --branch rust-implementation
cd aphid
cargo test
cargo build --release
```

Then run the binary obtained:

```sh
./target/release/aphid <arguments>
```

[git]: https://git-scm.com/
[rust stable toolchain]: https://www.rust-lang.org/tools/install
[torch]: https://pytorch.org/get-started/locally/


## Running Aphid

TODO: rust doc not written yet.
